@@ -9,13 +9,16 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
   tz = params_general[["desiredtz"]]
   epSizeShort = params_general[["windowsizes"]][1]
   epSizeLong = params_general[["windowsizes"]][2]
+  epSizeNonWear = params_general[["windowsizes"]][3]
+  myfun = NULL
   # Identify input data file extensions
   if (dir.exists(datadir) == FALSE) {
     stop("\nWhen working with external data, argument datadir is expected to be a directory")
   }
-  fnames_csv = dir(datadir,full.names = TRUE,pattern = "[.]csv")
-  fnames_awd = dir(datadir,full.names = TRUE,pattern = "[.]awd|[.]AWD")
-  if (length(fnames_csv) > 0 & length(fnames_awd) > 0) {
+  fnames_csv = dir(datadir, full.names = TRUE,pattern = "[.]csv")
+  fnames_awd = dir(datadir, full.names = TRUE,pattern = "[.]awd|[.]AWD")
+  fnames_xls = dir(datadir, full.names = TRUE,pattern = "[.]xls")
+  if (length(which(c(length(fnames_csv), length(fnames_awd), length(fnames_xls)) != 0)) > 1) {
     stop("Do not mix csv and awd files in the same data directory")
   } else {
     if (length(fnames_awd) > 0) {
@@ -23,11 +26,16 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
         stop("Specified dataFormat does not match the data")
       }
       fnames = fnames_awd
-    } else {
+    } else if (length(fnames_csv) > 0) {
       if (params_general[["dataFormat"]] == "actiwatch_awd") {
         stop("Specified dataFormat does not match the data")
       }
       fnames = fnames_csv
+    } else if (length(fnames_xls) > 0) {
+      if (params_general[["dataFormat"]] != "sensewear_xls") {
+        stop("Specified dataFormat does not match the data")
+      }
+      fnames = fnames_xls
     }
   }
   #-------------
@@ -69,6 +77,13 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
     dformc = 99
     dformn = "epochdata"
     sf = 100 # <= EXTRACT FROM FILE?
+  } else if (params_general[["dataFormat"]] == "sensewear_xls") {
+    deviceName = "Sensewear"
+    monn = "sensewear"
+    monc = 98
+    dformc = 98
+    dformn = "epochdata"
+    sf = 100 # <= EXTRACT FROM FILE?
   }
   
   # Before we look inside the epoch files we can already create templates
@@ -139,7 +154,7 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
     # include verbose info
     if (verbose == TRUE) {
       if (i  == 1) {
-        cat(paste0("\nLoading file: ", i))
+        cat(paste0("\nP1 file: ", i))
       } else {
         cat(paste0(" ", i))
       }
@@ -170,6 +185,23 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
         # extract date/timestamp from fileheader
         timestamp = unlist(strsplit(header," - "))[2]
         timestamp_POSIX = as.POSIXlt(timestamp, tz = tz)
+      } else if (params_general[["dataFormat"]] == "sensewear_xls") {
+        # read data
+        D = as.data.frame(readxl::read_excel(path = fnames[i], col_types = "text"))
+        # Convert timestamps which is read as Excel timestamp
+        timestamp_POSIX = format(as.POSIXct(as.numeric(D[, grep(pattern = "Time", x = colnames(D))]) * (60*60*24),
+                                            origin = "1899-12-30", tz = "GMT"))
+        timestamp_POSIX = as.POSIXct(timestamp_POSIX, tz = tz)
+        
+        D = D[, c("METs", "Step Counter", "Sleep")]
+        colnames(D) = c("ExtAct", "ExtStep", "ExtSleep")
+        D$ExtAct = as.numeric(D$ExtAct)
+        D$ExtStep = as.numeric(D$ExtStep)
+        D$ExtSleep = as.numeric(D$ExtSleep)
+        epochSize = difftime(timestamp_POSIX[2], timestamp_POSIX[1], 
+                             units = "secs")
+        epSizeShort = as.numeric(epochSize)
+        timestamp_POSIX = timestamp_POSIX[1]
       } else if (params_general[["dataFormat"]] == "actigraph_csv") {
         # check if file was exported with header:
         header_test = FALSE
@@ -180,12 +212,10 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
           df = data.frame(variable = tolower(variable), value = tmp[length(tmp)])
           return(df)
         }
-        
         AGh = NULL
         for (hh in header[2:9,1]) {
           AGh = rbind(AGh, splitHeader(hh))
         }
-        
         if (any(grepl("serialnumber", AGh$variable))) header_test = TRUE
         
         # rows to skip:
@@ -488,15 +518,14 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
                                             tz = tz)
       time_longEp_8601 = POSIXtime2iso8601(x = as.POSIXlt(time_longEp_num, tz = tz, origin = "1970-01-01"),
                                            tz = tz)
-      if (params_general[["dataFormat"]] != "actigraph_csv") {
+      if (params_general[["dataFormat"]] %in% c("actigraph_csv", "sensewear_xls") == FALSE) {
         M$metashort = data.frame(timestamp = time_shortEp_8601,
                                  accmetric = D[1:length(time_shortEp_8601),1],stringsAsFactors = FALSE)
-      } else if (params_general[["dataFormat"]] == "actigraph_csv") {
-        M$metashort = data.frame(timestamp = time_shortEp_8601)
-        M$metashort = cbind(M$metashort, D[1:length(time_shortEp_8601), ])
+      } else {
+        M$metashort = as.data.frame(cbind(time_shortEp_8601,
+                                          D[1:length(time_shortEp_8601), ]))
         colnames(M$metashort) = c("timestamp", colnames(D))
       }
-
       if (length(which(is.na(M$metashort$ZCY) == TRUE)) > 0) {
         # impute missing data by zero
         # if it is a lot then this will be detected as non-wear
@@ -513,6 +542,8 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
         imp = unlist(D[, 1])
       } else if (params_general[["dataFormat"]] == "actigraph_csv") {
         imp = unlist(D[, 1])
+      } else if (params_general[["dataFormat"]] == "sensewear_xls") {
+        imp = unlist(D[, 1])
       }
       navalues = which(is.na(imp) == TRUE)
       if (length(navalues) > 0) imp[navalues] = 1
@@ -524,9 +555,10 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
                              by = ((60/epSizeShort) * (epSizeLong/60)))]) / ((60/epSizeShort) * (epSizeLong/60)) # rolling mean
         imp4 = round(imp3 * 3) # create three level nonwear score from it, not really necessary for GGIR, but helps to retain some of the information
       } else if (length(grep(pattern = "actiwatch", x = params_general[["dataFormat"]], ignore.case = TRUE)) > 0 |
-                 params_general[["dataFormat"]] == "actigraph_csv") {
+                 params_general[["dataFormat"]] == "actigraph_csv" |
+                 params_general[["dataFormat"]] == "sensewear_xls") {
         # Using rolling 60 minute sum to indicate whether it is nonwear
-        imp2 = zoo::rollapply(imp, width = (1*3600) / epSizeShort, FUN = sum, fill = 0)
+        imp2 = zoo::rollapply(imp, width = ceiling(epSizeNonWear / epSizeShort), FUN = sum, fill = 0)
         imp4 = imp2
         imp4[which(imp2 > 0)] = 0
         imp4[which(imp2 == 0)] = 3 # If rolling average is zero then consider it nonwear
@@ -540,6 +572,20 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
       if (length(imp4) < LML) {
         imp4 = c(imp4, rep(0, LML - length(imp4)))
       }
+      if (params_general[["dataFormat"]] == "sensewear_xls") {
+        # Create myfun object, this to trigger outcome type specific analysis
+        myfun = list(FUN = NA,
+                     parameters = NA, 
+                     expected_sample_rate = NA, 
+                     expected_unit = "g", 
+                     colnames = c("ExtAct", "ExtStep", "ExtSleep"),
+                     outputres = epSizeShort,
+                     minlength = NA,
+                     outputtype = c("numeric", "numeric", "numeric"),
+                     aggfunction = NA,
+                     timestamp = F, 
+                     reporttype = c("scalar", "event", "type"))
+      }
       # create data.frame for metalong, note that light and temperature are just set at zero
       M$metalong = data.frame(timestamp = time_longEp_8601,nonwearscore = imp4, #rep(0,LML)
                               clippingscore = rep(0,LML), lightmean = rep(0,LML),
@@ -550,7 +596,7 @@ convertEpochData = function(datadir = c(), metadatadir = c(),
       M$wday = as.POSIXlt(starttime)$wday + 1
       # Save these files as new meta-file
       filefoldername = NA
-      save(M, C, I, filename_dir, filefoldername,
+      save(M, C, I, myfun, filename_dir, filefoldername,
            file = outputFileName)
       Sys.setlocale("LC_TIME", Syslocale) # set language to English
     }
